@@ -55,7 +55,8 @@ enum errMsgs {
     JW_ERR_NOT_IMPLEMENTED,
     JW_ERR_ILLEGAL_PARAM_NUM,
     JW_ERR_MEM,
-    JW_ERR_LIST_INDEX
+    JW_ERR_LIST_INDEX,
+    JW_ERR_SEQUENCE
 };
 
 
